@@ -80,6 +80,10 @@ var searchData=
   ['libinput_5fdevice_5fconfig_5fmiddle_5femulation_5fget_5fenabled',['libinput_device_config_middle_emulation_get_enabled',['../group__config.html#ga4669a9e2eeda7ddd648d340935c40ada',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5fmiddle_5femulation_5fis_5favailable',['libinput_device_config_middle_emulation_is_available',['../group__config.html#gad9d32f1fd776fa112e5eaac6419de6b7',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5fmiddle_5femulation_5fset_5fenabled',['libinput_device_config_middle_emulation_set_enabled',['../group__config.html#ga584d862a116fb0a26cc95304f8c13eb1',1,'libinput.h']]],
+  ['libinput_5fdevice_5fconfig_5frotation_5fget_5fangle',['libinput_device_config_rotation_get_angle',['../group__config.html#gaf57b8746f6f56d2410aa71f29416c9a2',1,'libinput.h']]],
+  ['libinput_5fdevice_5fconfig_5frotation_5fget_5fdefault_5fangle',['libinput_device_config_rotation_get_default_angle',['../group__config.html#ga820ae96544109707d3bfef41a6114ea7',1,'libinput.h']]],
+  ['libinput_5fdevice_5fconfig_5frotation_5fis_5favailable',['libinput_device_config_rotation_is_available',['../group__config.html#ga2fab82b2ba0cac9a645c1ce8e32df448',1,'libinput.h']]],
+  ['libinput_5fdevice_5fconfig_5frotation_5fset_5fangle',['libinput_device_config_rotation_set_angle',['../group__config.html#ga136b2f7753235c5d2a9fb2762a040eef',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5fscroll_5fget_5fbutton',['libinput_device_config_scroll_get_button',['../group__config.html#ga83623da437d0114b8e3ac29ab771d799',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5fscroll_5fget_5fdefault_5fbutton',['libinput_device_config_scroll_get_default_button',['../group__config.html#gad4aacefb10fab1e401e211ee9ce0c1e6',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5fscroll_5fget_5fdefault_5fmethod',['libinput_device_config_scroll_get_default_method',['../group__config.html#ga844ea06b952aaee8e0643d85d351afb6',1,'libinput.h']]],
@@ -128,7 +132,9 @@ var searchData=
   ['libinput_5fdevice_5fref',['libinput_device_ref',['../group__device.html#ga3335d55a50f0c2fb0c5f496a3105d467',1,'libinput.h']]],
   ['libinput_5fdevice_5fset_5fseat_5flogical_5fname',['libinput_device_set_seat_logical_name',['../group__device.html#ga9f76acc43c8684a13f232073ee829b50',1,'libinput.h']]],
   ['libinput_5fdevice_5fset_5fuser_5fdata',['libinput_device_set_user_data',['../group__device.html#ga6243ad6005b2ce2a5ecfd1b04787fe93',1,'libinput.h']]],
+  ['libinput_5fdevice_5ftablet_5fpad_5fget_5fmode_5fgroup',['libinput_device_tablet_pad_get_mode_group',['../group__tablet__pad__modes.html#ga6260a3ec1a1ba152dcf7eed18c8a154b',1,'libinput.h']]],
   ['libinput_5fdevice_5ftablet_5fpad_5fget_5fnum_5fbuttons',['libinput_device_tablet_pad_get_num_buttons',['../group__device.html#ga2c5a5703982bcedc71a0470278258710',1,'libinput.h']]],
+  ['libinput_5fdevice_5ftablet_5fpad_5fget_5fnum_5fmode_5fgroups',['libinput_device_tablet_pad_get_num_mode_groups',['../group__tablet__pad__modes.html#ga4d246393e68fd7c415a6936c92a23643',1,'libinput.h']]],
   ['libinput_5fdevice_5ftablet_5fpad_5fget_5fnum_5frings',['libinput_device_tablet_pad_get_num_rings',['../group__device.html#ga624cd4cb5fcd049fe88b2ab5f0a649cb',1,'libinput.h']]],
   ['libinput_5fdevice_5ftablet_5fpad_5fget_5fnum_5fstrips',['libinput_device_tablet_pad_get_num_strips',['../group__device.html#gaa0696b32b500ccc0876396a184e22c01',1,'libinput.h']]],
   ['libinput_5fdevice_5funref',['libinput_device_unref',['../group__device.html#ga857340e2dab06c7f7d84173a5a1fa427',1,'libinput.h']]],
@@ -200,17 +206,19 @@ var searchData=
   ['libinput_5fevent_5fpointer_5fmotion_5fabsolute',['LIBINPUT_EVENT_POINTER_MOTION_ABSOLUTE',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7ca5e277107f22df970e882ef76dd6cc315',1,'libinput.h']]],
   ['libinput_5fevent_5ftablet_5fpad',['libinput_event_tablet_pad',['../structlibinput__event__tablet__pad.html',1,'']]],
   ['libinput_5fevent_5ftablet_5fpad_5fbutton',['LIBINPUT_EVENT_TABLET_PAD_BUTTON',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7ca8b1be0a98eba05bd046a15ad32b18a74',1,'libinput.h']]],
-  ['libinput_5fevent_5ftablet_5fpad_5fget_5fbase_5fevent',['libinput_event_tablet_pad_get_base_event',['../group__event__tablet.html#ga33eb585eb7da3f35c083084a1f4e5586',1,'libinput.h']]],
-  ['libinput_5fevent_5ftablet_5fpad_5fget_5fbutton_5fnumber',['libinput_event_tablet_pad_get_button_number',['../group__event__tablet.html#ga4339cf54b0a511599595e8483eea360d',1,'libinput.h']]],
-  ['libinput_5fevent_5ftablet_5fpad_5fget_5fbutton_5fstate',['libinput_event_tablet_pad_get_button_state',['../group__event__tablet.html#ga92235cd641c3003f18c0cb5bbf2e3c88',1,'libinput.h']]],
-  ['libinput_5fevent_5ftablet_5fpad_5fget_5fring_5fnumber',['libinput_event_tablet_pad_get_ring_number',['../group__event__tablet.html#gae866be98b773edcf95ad9a36b5bbacb1',1,'libinput.h']]],
-  ['libinput_5fevent_5ftablet_5fpad_5fget_5fring_5fposition',['libinput_event_tablet_pad_get_ring_position',['../group__event__tablet.html#ga77526f6732ae51aaab3973a69239a25e',1,'libinput.h']]],
-  ['libinput_5fevent_5ftablet_5fpad_5fget_5fring_5fsource',['libinput_event_tablet_pad_get_ring_source',['../group__event__tablet.html#ga96102ae975b4a28f0a02d035dd11496d',1,'libinput.h']]],
-  ['libinput_5fevent_5ftablet_5fpad_5fget_5fstrip_5fnumber',['libinput_event_tablet_pad_get_strip_number',['../group__event__tablet.html#ga32792a10d7f86900a4f94e63037f68b6',1,'libinput.h']]],
-  ['libinput_5fevent_5ftablet_5fpad_5fget_5fstrip_5fposition',['libinput_event_tablet_pad_get_strip_position',['../group__event__tablet.html#gaeff6c2c21b2b02e4d2f9b0b23db27dea',1,'libinput.h']]],
-  ['libinput_5fevent_5ftablet_5fpad_5fget_5fstrip_5fsource',['libinput_event_tablet_pad_get_strip_source',['../group__event__tablet.html#ga9dded037d0f4dbfc9ffa67795118c431',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5fpad_5fget_5fbase_5fevent',['libinput_event_tablet_pad_get_base_event',['../group__event__tablet__pad.html#ga33eb585eb7da3f35c083084a1f4e5586',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5fpad_5fget_5fbutton_5fnumber',['libinput_event_tablet_pad_get_button_number',['../group__event__tablet__pad.html#ga4339cf54b0a511599595e8483eea360d',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5fpad_5fget_5fbutton_5fstate',['libinput_event_tablet_pad_get_button_state',['../group__event__tablet__pad.html#ga92235cd641c3003f18c0cb5bbf2e3c88',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5fpad_5fget_5fmode',['libinput_event_tablet_pad_get_mode',['../group__event__tablet__pad.html#ga7ba64faefd071d101d21fd347720ea21',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5fpad_5fget_5fmode_5fgroup',['libinput_event_tablet_pad_get_mode_group',['../group__event__tablet__pad.html#ga154b2b7af0b8913e27d8012530f0aaa3',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5fpad_5fget_5fring_5fnumber',['libinput_event_tablet_pad_get_ring_number',['../group__event__tablet__pad.html#gae866be98b773edcf95ad9a36b5bbacb1',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5fpad_5fget_5fring_5fposition',['libinput_event_tablet_pad_get_ring_position',['../group__event__tablet__pad.html#ga77526f6732ae51aaab3973a69239a25e',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5fpad_5fget_5fring_5fsource',['libinput_event_tablet_pad_get_ring_source',['../group__event__tablet__pad.html#ga96102ae975b4a28f0a02d035dd11496d',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5fpad_5fget_5fstrip_5fnumber',['libinput_event_tablet_pad_get_strip_number',['../group__event__tablet__pad.html#ga32792a10d7f86900a4f94e63037f68b6',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5fpad_5fget_5fstrip_5fposition',['libinput_event_tablet_pad_get_strip_position',['../group__event__tablet__pad.html#gaeff6c2c21b2b02e4d2f9b0b23db27dea',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5fpad_5fget_5fstrip_5fsource',['libinput_event_tablet_pad_get_strip_source',['../group__event__tablet__pad.html#ga9dded037d0f4dbfc9ffa67795118c431',1,'libinput.h']]],
   ['libinput_5fevent_5ftablet_5fpad_5fget_5ftime',['libinput_event_tablet_pad_get_time',['../group__event__tablet.html#ga126efe81b0c73a14ac71419ee5683f1b',1,'libinput.h']]],
-  ['libinput_5fevent_5ftablet_5fpad_5fget_5ftime_5fusec',['libinput_event_tablet_pad_get_time_usec',['../group__event__tablet.html#ga86dc23306e80986a819e3764a9847108',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5fpad_5fget_5ftime_5fusec',['libinput_event_tablet_pad_get_time_usec',['../group__event__tablet__pad.html#ga86dc23306e80986a819e3764a9847108',1,'libinput.h']]],
   ['libinput_5fevent_5ftablet_5fpad_5fring',['LIBINPUT_EVENT_TABLET_PAD_RING',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7ca243f5e4a62b72c2ff15d2b025a91e70f',1,'libinput.h']]],
   ['libinput_5fevent_5ftablet_5fpad_5fstrip',['LIBINPUT_EVENT_TABLET_PAD_STRIP',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7ca2b66dc7ee62f549a3f63217977a5a306',1,'libinput.h']]],
   ['libinput_5fevent_5ftablet_5ftool',['libinput_event_tablet_tool',['../structlibinput__event__tablet__tool.html',1,'']]],
@@ -308,12 +316,24 @@ var searchData=
   ['libinput_5fseat_5funref',['libinput_seat_unref',['../group__seat.html#ga81d52d0e9332f07c39a899c8c2fd3400',1,'libinput.h']]],
   ['libinput_5fset_5fuser_5fdata',['libinput_set_user_data',['../group__base.html#gac1a020ab0a0da92749e24e80538ab28f',1,'libinput.h']]],
   ['libinput_5fsuspend',['libinput_suspend',['../group__base.html#ga60662dc666f6188dc207467c9d8e99ab',1,'libinput.h']]],
-  ['libinput_5ftablet_5fpad_5fring_5faxis_5fsource',['libinput_tablet_pad_ring_axis_source',['../group__event__tablet.html#gafb0259f1d3f79e4ecaa74eb307186473',1,'libinput.h']]],
-  ['libinput_5ftablet_5fpad_5fring_5fsource_5ffinger',['LIBINPUT_TABLET_PAD_RING_SOURCE_FINGER',['../group__event__tablet.html#ggafb0259f1d3f79e4ecaa74eb307186473acf6148ddec89e3307ab0df053da1e96f',1,'libinput.h']]],
-  ['libinput_5ftablet_5fpad_5fring_5fsource_5funknown',['LIBINPUT_TABLET_PAD_RING_SOURCE_UNKNOWN',['../group__event__tablet.html#ggafb0259f1d3f79e4ecaa74eb307186473a0a973dc16228d89efd0ef5995b0e5881',1,'libinput.h']]],
-  ['libinput_5ftablet_5fpad_5fstrip_5faxis_5fsource',['libinput_tablet_pad_strip_axis_source',['../group__event__tablet.html#ga09790bd108d3a288bb387aeb3a9a2dd8',1,'libinput.h']]],
-  ['libinput_5ftablet_5fpad_5fstrip_5fsource_5ffinger',['LIBINPUT_TABLET_PAD_STRIP_SOURCE_FINGER',['../group__event__tablet.html#gga09790bd108d3a288bb387aeb3a9a2dd8add543fc4601c82698d588892bc9c9de8',1,'libinput.h']]],
-  ['libinput_5ftablet_5fpad_5fstrip_5fsource_5funknown',['LIBINPUT_TABLET_PAD_STRIP_SOURCE_UNKNOWN',['../group__event__tablet.html#gga09790bd108d3a288bb387aeb3a9a2dd8a5ed957a8e351e24e8b1efe7361694a74',1,'libinput.h']]],
+  ['libinput_5ftablet_5fpad_5fmode_5fgroup',['libinput_tablet_pad_mode_group',['../structlibinput__tablet__pad__mode__group.html',1,'']]],
+  ['libinput_5ftablet_5fpad_5fmode_5fgroup_5fbutton_5fis_5ftoggle',['libinput_tablet_pad_mode_group_button_is_toggle',['../group__tablet__pad__modes.html#gade239729d9a9449513cd46f8b9e00ba5',1,'libinput.h']]],
+  ['libinput_5ftablet_5fpad_5fmode_5fgroup_5fget_5findex',['libinput_tablet_pad_mode_group_get_index',['../group__tablet__pad__modes.html#ga6aafbf3c20d52ea0a4490e7841ee90ba',1,'libinput.h']]],
+  ['libinput_5ftablet_5fpad_5fmode_5fgroup_5fget_5fmode',['libinput_tablet_pad_mode_group_get_mode',['../group__tablet__pad__modes.html#ga6665cafeed47b6b061c702760e7654a5',1,'libinput.h']]],
+  ['libinput_5ftablet_5fpad_5fmode_5fgroup_5fget_5fnum_5fmodes',['libinput_tablet_pad_mode_group_get_num_modes',['../group__tablet__pad__modes.html#ga63f52e1cdcde522fe6990e4407782d4b',1,'libinput.h']]],
+  ['libinput_5ftablet_5fpad_5fmode_5fgroup_5fget_5fuser_5fdata',['libinput_tablet_pad_mode_group_get_user_data',['../group__tablet__pad__modes.html#ga1b78ddbdbe034594f86bf26dca5dd13c',1,'libinput.h']]],
+  ['libinput_5ftablet_5fpad_5fmode_5fgroup_5fhas_5fbutton',['libinput_tablet_pad_mode_group_has_button',['../group__tablet__pad__modes.html#ga6e6efcb715243ec826023071a9271c81',1,'libinput.h']]],
+  ['libinput_5ftablet_5fpad_5fmode_5fgroup_5fhas_5fring',['libinput_tablet_pad_mode_group_has_ring',['../group__tablet__pad__modes.html#ga22a228d4e60c38c5d57578291f0947aa',1,'libinput.h']]],
+  ['libinput_5ftablet_5fpad_5fmode_5fgroup_5fhas_5fstrip',['libinput_tablet_pad_mode_group_has_strip',['../group__tablet__pad__modes.html#ga54c2c799139404a00a18d1dda1c7d3c9',1,'libinput.h']]],
+  ['libinput_5ftablet_5fpad_5fmode_5fgroup_5fref',['libinput_tablet_pad_mode_group_ref',['../group__tablet__pad__modes.html#ga24f9fe4abfed860c6fd9dbd6963df79b',1,'libinput.h']]],
+  ['libinput_5ftablet_5fpad_5fmode_5fgroup_5fset_5fuser_5fdata',['libinput_tablet_pad_mode_group_set_user_data',['../group__tablet__pad__modes.html#ga321255fc232405a48569a631444b0f69',1,'libinput.h']]],
+  ['libinput_5ftablet_5fpad_5fmode_5fgroup_5funref',['libinput_tablet_pad_mode_group_unref',['../group__tablet__pad__modes.html#ga486ea28bdecd75500916367972d6bfe7',1,'libinput.h']]],
+  ['libinput_5ftablet_5fpad_5fring_5faxis_5fsource',['libinput_tablet_pad_ring_axis_source',['../group__event__tablet__pad.html#gafb0259f1d3f79e4ecaa74eb307186473',1,'libinput.h']]],
+  ['libinput_5ftablet_5fpad_5fring_5fsource_5ffinger',['LIBINPUT_TABLET_PAD_RING_SOURCE_FINGER',['../group__event__tablet__pad.html#ggafb0259f1d3f79e4ecaa74eb307186473acf6148ddec89e3307ab0df053da1e96f',1,'libinput.h']]],
+  ['libinput_5ftablet_5fpad_5fring_5fsource_5funknown',['LIBINPUT_TABLET_PAD_RING_SOURCE_UNKNOWN',['../group__event__tablet__pad.html#ggafb0259f1d3f79e4ecaa74eb307186473a0a973dc16228d89efd0ef5995b0e5881',1,'libinput.h']]],
+  ['libinput_5ftablet_5fpad_5fstrip_5faxis_5fsource',['libinput_tablet_pad_strip_axis_source',['../group__event__tablet__pad.html#ga09790bd108d3a288bb387aeb3a9a2dd8',1,'libinput.h']]],
+  ['libinput_5ftablet_5fpad_5fstrip_5fsource_5ffinger',['LIBINPUT_TABLET_PAD_STRIP_SOURCE_FINGER',['../group__event__tablet__pad.html#gga09790bd108d3a288bb387aeb3a9a2dd8add543fc4601c82698d588892bc9c9de8',1,'libinput.h']]],
+  ['libinput_5ftablet_5fpad_5fstrip_5fsource_5funknown',['LIBINPUT_TABLET_PAD_STRIP_SOURCE_UNKNOWN',['../group__event__tablet__pad.html#gga09790bd108d3a288bb387aeb3a9a2dd8a5ed957a8e351e24e8b1efe7361694a74',1,'libinput.h']]],
   ['libinput_5ftablet_5ftool',['libinput_tablet_tool',['../structlibinput__tablet__tool.html',1,'']]],
   ['libinput_5ftablet_5ftool_5fget_5fserial',['libinput_tablet_tool_get_serial',['../group__event__tablet.html#gac8084f1e2891ccaa9be5faedf4310f78',1,'libinput.h']]],
   ['libinput_5ftablet_5ftool_5fget_5ftool_5fid',['libinput_tablet_tool_get_tool_id',['../group__event__tablet.html#ga5ba26a193ce809fab9234b2253bcfff8',1,'libinput.h']]],
