@@ -955,8 +955,11 @@ tp_need_motion_history_reset(struct tp_dispatch *tp)
 {
 	bool rc = false;
 
-	/* semi-mt finger postions may "jump" when nfingers changes */
-	if (tp->semi_mt && tp->nfingers_down != tp->old_nfingers_down)
+	/* Changing the numbers of fingers can cause a jump in the
+	 * coordinates, always reset the motion history for all touches when
+	 * that happens.
+	 */
+	if (tp->nfingers_down != tp->old_nfingers_down)
 		return true;
 
 	/* if we're transitioning between slots and fake touches in either
