@@ -225,6 +225,37 @@ dwt_default(struct libinput_device *device)
 		return "disabled";
 }
 
+static char *
+rotation_default(struct libinput_device *device)
+{
+	char *str;
+	double angle;
+
+	if (!libinput_device_config_rotation_is_available(device)) {
+		xasprintf(&str, "n/a");
+		return str;
+	}
+
+	angle = libinput_device_config_rotation_get_angle(device);
+	xasprintf(&str, "%.1f", angle);
+	return str;
+}
+
+static void
+print_pad_info(struct libinput_device *device)
+{
+	int nbuttons, nrings, nstrips;
+
+	nbuttons = libinput_device_tablet_pad_get_num_buttons(device);
+	nrings = libinput_device_tablet_pad_get_num_rings(device);
+	nstrips = libinput_device_tablet_pad_get_num_strips(device);
+
+	printf("Pad:\n");
+	printf("	Rings:   %d\n", nrings);
+	printf("	Strips:  %d\n", nstrips);
+	printf("	Buttons: %d\n", nbuttons);
+}
+
 static void
 print_device_notify(struct libinput_event *ev)
 {
@@ -301,6 +332,14 @@ print_device_notify(struct libinput_event *ev)
 	printf("Accel profiles:   %s\n", str);
 	free(str);
 
+	str = rotation_default(dev);
+	printf("Rotation:         %s\n", str);
+	free(str);
+
+	if (libinput_device_has_capability(dev,
+					   LIBINPUT_DEVICE_CAP_TABLET_PAD))
+		print_pad_info(dev);
+
 	printf("\n");
 }
 
